# yacht
*YAML conversion to HTML*

Whilst static web pages are less popular nowadays, this project aims to simplify(?) their creation by using a more human friendly markup language. 

No more searching for unterminated tags and improved readability - thanks to YAML's indented structure

## Usage:
for now you can run it as 

`python3 convert.py > output.html`

propper support for parameters will be added soon
